"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const versions_enum_1 = require("@cli/versions/versions.enum");
const command_1 = require("@oclif/command");
const base_1 = require("@utils/base");
const providers_1 = require("@utils/providers");
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
class VersionsCommand extends base_1.BaseCommand {
    exec({ flags, args, resolver }) {
        const { project, type } = flags;
        let { version } = args;
        if (!version) {
            version = type;
        }
        return rxjs_1.concat(providers_1.NpmProvider.exec(['version', version], [], { cwd: resolver.cwd(project) }), rxjs_1.Observable.create((subscriber) => {
            subscriber.next(resolver.pack(project));
            subscriber.complete();
        }).pipe(operators_1.switchMap(({ version }) => rxjs_1.concat(providers_1.GitProvider.commit(`${project}@${version}`), providers_1.GitProvider.tag(`${project}@${version}`)))));
    }
}
VersionsCommand.description = 'Измениие версии';
VersionsCommand.examples = [
    `$ mnpm version -p=test-project`
];
VersionsCommand.flags = {
    help: command_1.flags.help({ char: 'h' }),
    project: command_1.flags.string({ char: 'p', description: 'Имя пакета' }),
    config: command_1.flags.string({ char: 'c', description: 'Файл настроек', default: '.mnpmrc', required: true }),
    type: command_1.flags.enum({ char: 't', description: 'Тип релиза', options: Object.values(versions_enum_1.Versions) })
};
VersionsCommand.args = [{
        name: 'version',
        description: 'Новая версия'
    }];
exports.VersionsCommand = VersionsCommand;
