"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const config_1 = require("@utils/config");
const providers_1 = require("@utils/providers");
const rxjs_1 = require("rxjs");
class BaseCommand extends command_1.default {
    static normalizeConfig(parsed, config) {
        const cwd = parsed.flags.cwd || config.cwd;
        const { resolver, allowedBranches } = config, otherConfig = tslib_1.__rest(config, ["resolver", "allowedBranches"]);
        return Object.assign({}, parsed, { resolver, flags: Object.assign({ allowedBranches: allowedBranches || ['master'] }, otherConfig, parsed.flags, { cwd }) });
    }
    async isAllowedCommand({ flags }) {
        const { allowedBranches, pureGit } = flags;
        if (!await providers_1.GitProvider.is(allowedBranches).toPromise()) {
            console.error(`Операция '${this.id}' разрешена только только для следующих бранчей: ${allowedBranches.join(', ')}`);
            process.exit(1);
        }
        if (pureGit && !await providers_1.GitProvider.isClean().toPromise()) {
            console.error(`Репозиторий содержит незакомиченные изменения.`);
            process.exit(1);
        }
    }
    async run() {
        const parsed = this.parse(this.constructor);
        const configFile = parsed.flags.config;
        const config = config_1.Config.parse(configFile, this.id);
        const normalizedConfig = BaseCommand.normalizeConfig(Object.assign({}, parsed, { id: this.id }), config);
        await this.isAllowedCommand(normalizedConfig);
        const project = normalizedConfig.flags.project;
        if (project) {
            return this.exec(normalizedConfig).toPromise();
        }
        else {
            return this.forAll(normalizedConfig).toPromise();
        }
    }
    forAll({ flags, args, resolver }) {
        return rxjs_1.concat(...[...resolver.keys()].map(project => this.exec({ flags: Object.assign({}, flags, { project }), args, resolver })));
    }
}
exports.BaseCommand = BaseCommand;
