"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const template_1 = require("@utils/template");
const child_process_1 = require("child_process");
const rxjs_1 = require("rxjs");
const parseCmd = require("string-argv");
class ExecProvider {
    static exec(cmd, options = {}) {
        const { cwd } = options;
        let finalCmd = cmd;
        if (typeof cmd === 'string') {
            finalCmd = parseCmd(cmd);
        }
        finalCmd = finalCmd.map(str => template_1.template(str, options));
        const command = finalCmd.shift();
        return rxjs_1.Observable.create((subscriber) => {
            console.log(`\nRun in ${cwd || process.cwd()}\n--> ${finalCmd.join(' ')}\n`);
            const child = child_process_1.spawn(command, finalCmd, { cwd, stdio: 'inherit' });
            child.on('close', (code) => {
                const withError = code.toString() !== '0';
                subscriber.next(child);
                withError
                    ? subscriber.error(new Error(`Процесс закончился с кодом ${code}`))
                    : subscriber.complete();
            });
            return () => subscriber.unsubscribe();
        });
    }
}
exports.ExecProvider = ExecProvider;
