"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const rxjs_1 = require("rxjs");
const internal_compatibility_1 = require("rxjs/internal-compatibility");
const exec_provider_1 = require("./exec.provider");
class GitProvider {
    static is(branchName) {
        const names = Array.isArray(branchName) ? branchName : [branchName];
        return internal_compatibility_1.fromPromise(new Promise((resolve, reject) => {
            const git = child_process_1.exec('git symbolic-ref --short HEAD');
            git.stdout.on('data', data => resolve(names.includes(data.trim())));
        }));
    }
    static isClean() {
        return internal_compatibility_1.fromPromise(new Promise((resolve, reject) => {
            const git = child_process_1.exec('git status --porcelain --untracked-files=no');
            git.stdout.on('data', data => resolve(!data.trim()));
            git.on('close', () => resolve(true));
        }));
    }
    static commit(message) {
        return rxjs_1.concat(GitProvider.add(), exec_provider_1.ExecProvider.exec(['git', 'commit', '-m', message]));
    }
    static add() {
        return exec_provider_1.ExecProvider.exec('git add .');
    }
    static tag(tag) {
        return exec_provider_1.ExecProvider.exec(['git', 'tag', tag]);
    }
}
exports.GitProvider = GitProvider;
