"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
class Resolver {
    constructor(paths) {
        this.normalize = (path) => {
            let fullPath = path_1.join(process.cwd(), path);
            if (fullPath.endsWith('*')) {
                fullPath = fullPath.replace(/\*$/g, '');
                const result = fs_1.readdirSync(fullPath);
                return result
                    .map(dir => path_1.join(fullPath, dir))
                    .filter(dir => fs_1.statSync(dir).isDirectory());
            }
            else {
                return [fullPath];
            }
        };
        this.paths = new Map(paths
            .map(this.normalize)
            .reduce((prev, current) => prev.concat(current), [])
            .map(path => {
            const packInfo = JSON.parse(fs_1.readFileSync(path_1.join(path, 'package.json')).toString());
            return [packInfo.name, path];
        }));
    }
    cwd(packageName) {
        return this.paths.get(packageName);
    }
    keys() {
        return this.paths.keys();
    }
    values() {
        return this.paths.values();
    }
    pack(packageName) {
        const cwd = this.cwd(packageName);
        return JSON.parse(fs_1.readFileSync(path_1.join(cwd, 'package.json')).toString());
    }
}
exports.Resolver = Resolver;
